@@ -26,7 +26,7 @@ class Resource
     @id or raise ResourceNotFoundError, id.to_s
 
     @type = cache.fetch_or_add(%{resource_type/#{@id}}) do
-      r = db[:resource][:id => @id]
+      r = db[:resource][:id => @id] or raise ResourceNotFoundError, @id.to_s
 
       if r[:uriref]
         'Uriref'
@@ -36,8 +36,6 @@ class Resource
         case r[:label]
         when 'member', 'message', 'statement', 'vote'
           r[:label].capitalize
-        when nil
-          raise ResourceNotFoundError, @id.to_s
         else
           raise RuntimeError,
             sprintf(_("Unknown resource type '%s'"), Rack::Utils.escape_html(r[:label]))
@@ -375,7 +373,7 @@ ORDER BY ?msg}, :parent => @id) {|ds| ds.key = :msg }
   def rss(maker)
     item = maker.items.new_item
     item.link = @request.base + @id.to_s
-    item.date = @message.date.to_time
+    item.date = @message.first_date.to_time
 
     item.title = escape_title(@translation.content.title)
     item.dc_language = @translation.lang
@@ -478,7 +476,7 @@ class MemberComponent < ResourceComponent
     maker.channel.title = maker.channel.description = @title
     maker.channel.link = File.join(@request.base, @location)
 
-    @messages_dataset[0]
+    @messages_dataset
   end
 end
 
