@@ -1,6 +1,6 @@
 # Samizdat text content plugin superclass
 #
-#   Copyright (c) 2002-2009  Dmitry Borodaenko <angdraug@debian.org>
+#   Copyright (c) 2002-2011  Dmitry Borodaenko <angdraug@debian.org>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
@@ -31,6 +31,10 @@ class ContentInlinePlugin < Plugin
     ''
   end
 
+  def safe_html?
+    false
+  end
+
   def cut(mode, body)
     case mode
     when :short
