@@ -1,6 +1,6 @@
 # Samizdat default text renderer plugin
 #
-#   Copyright (c) 2002-2009  Dmitry Borodaenko <angdraug@debian.org>
+#   Copyright (c) 2002-2011  Dmitry Borodaenko <angdraug@debian.org>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
@@ -17,7 +17,7 @@ class TextDefaultPlugin < ContentInlinePlugin
   end
 
   def render(request, mode, body)
-    CGI.escapeHTML(body).split(/^\s*$/).collect {|p|
+    Rack::Utils.escape_html(body).split(/^\s*$/).collect {|p|
       '<p>' + p.gsub(URI::ABS_URI_REF) {|url|
         scheme, host = $1, $4   # see URI::REGEXP::PATTERN::X_ABS_URI
         if AUTOURL_SCHEMES.include?(scheme) and not host.nil?
