@@ -1,6 +1,6 @@
 # Samizdat verbatim plain text renderer plugin
 #
-#   Copyright (c) 2002-2009  Dmitry Borodaenko <angdraug@debian.org>
+#   Copyright (c) 2002-2011  Dmitry Borodaenko <angdraug@debian.org>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
@@ -17,7 +17,7 @@ class PlainTextPlugin < ContentInlinePlugin
   end
 
   def render(request, mode, body)
-    "<pre>#{CGI.escapeHTML(body)}</pre>"
+    "<pre>#{Rack::Utils.escape_html(body)}</pre>"
   end
 
   def format_name
