@@ -1,6 +1,6 @@
 # Samizdat Squish query renderer plugin
 #
-#   Copyright (c) 2002-2009  Dmitry Borodaenko <angdraug@debian.org>
+#   Copyright (c) 2002-2011  Dmitry Borodaenko <angdraug@debian.org>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
@@ -35,6 +35,10 @@ class SquishPlugin < ContentInlinePlugin
   def format_name
     _('Squish query')
   end
+
+  def safe_html?
+    true
+  end
 end
 
 PluginClasses.instance['squish'] = SquishPlugin
