@@ -1,6 +1,6 @@
 # Samizdat Textile formatted text renderer plugin
 #
-#   Copyright (c) 2002-2009  Dmitry Borodaenko <angdraug@debian.org>
+#   Copyright (c) 2002-2011  Dmitry Borodaenko <angdraug@debian.org>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
@@ -28,7 +28,7 @@ begin
 rescue LoadError
   class RedCloth < String
     def to_html   # revert to text/plain
-      "<pre>#{CGI.escapeHTML(self)}</pre>"
+      "<pre>#{Rack::Utils.escape_html(self)}</pre>"
     end
   end
 end
